// Copyright (c) 2007 Alberto Ruiz <aruiz@gnome.org>
// All Rights Reserved.
// Published under the BSD License.

using Clutter;
using GLib;

public class SuperOh : Clutter.Group {
  private Timeline timeline;
  public uint n_hands { get; construct; default = 5; }

  construct {
    timeline = new Timeline.for_duration (6000);

    timeline.loop = true;
    timeline.new_frame += frame_cb;

    create_hands();
  }

  public SuperOh (uint n_hands) { }

  private void create_hands () {
    Clutter.Texture hand_texture;

    try {
      hand_texture = new Texture.from_file ("redhand.png");
    }
    catch (Error e) {
      stderr.printf ("Unable to load redhand.png: %s", e.message);
      return;
    }

    int w, h;
    hand_texture.get_size (out w, out h);

    var stage = Stage.get_default();

    for (uint i = 0; i < n_hands ; i++) {
      Actor hand = new CloneTexture (hand_texture);
      
      double x = stage.get_width () / 2.
                 + get_radius ()
                 * Math.cos (i * GLib.Math.PI / (n_hands / 2.))
                 - w / 2.;

      double y = stage.get_height () / 2.
                 + get_radius ()
                 * Math.sin (i * GLib.Math.PI / (n_hands / 2.))
                 - h / 2.;

      hand.set_position ((int) x, (int) y);
      hand.show();

      add_actor (hand);
    }
  }

  public void spin () { timeline.start (); }

  private uint get_radius () {
    var stage = Stage.get_default();

    return (stage.get_width () + stage.get_height ()) / 6;
  }

  private void frame_cb (Clutter.Timeline tl, int frame_num) {
    var stage = Stage.get_default();

    set_rotation (RotateAxis.Z_AXIS, (double) frame_num,
                  (int) stage.get_width () / 2,
		  (int) stage.get_height () / 2,
                  0);
      
    for (int i = 0; i < n_hands; i++) {
      Actor hand = get_nth_child(i);
      double angle = frame_num * -1.;
      int width, height;

      hand.get_size (out width, out height);
      
      hand.set_rotation (RotateAxis.X_AXIS, angle,
                         0,
                         width / 2,
                         height / 2);
      hand.set_rotation (RotateAxis.Y_AXIS, angle,
                         width / 2,
                         0,
                         height / 2);
    }
  }

}

class TestActors : Object {
  private SuperOh hands;

  private bool button_cb (Stage stage, ButtonEvent event_) {
    int x, y;
    ((Event) event_).get_coords (out x, out y);

    Actor hand = stage.get_actor_at_pos (x, y);
    if (hand == null)
      return false;

    if (typeof (Texture) == hand.get_type () ||
        typeof (CloneTexture) == hand.get_type ()) {
      hand.hide();
      return true;
    }

    return false;
  }

  private bool key_cb (Stage stage, KeyEvent event_) {
    if (event_.get_symbol () == (uint)'q') {
      Clutter.main_quit();
      return true;
    }

    return false;
  }

  construct {
    var stage = (Stage) Stage.get_default ();

    stage.set_size(800, 600);
    stage.button_press_event += button_cb;
    stage.key_press_event += key_cb;

    Clutter.Color background;
    Clutter.Color.parse ("#61648cff", out background);
    stage.set_color (background);

    hands = new SuperOh (5);

    stage.add_actor (hands);
    stage.show_all ();
  }

  public void run () {
    hands.spin ();
    Clutter.main ();
  }

  static void main (string[] args) {
    Clutter.init (ref args);

    var test = new TestActors ();
    test.run ();
  }
}
