using GLib;
using Clutter;

class TestBehave : Object {
  public Clutter.Rectangle rect;
  public Clutter.Texture hand;
  public Clutter.Behaviour o_behave;
  public Clutter.BehaviourPath p_behave;
  public Clutter.Timeline timeline;

  const Knot[] poly_knots = {
    {   0,   0 },
    {   0, 300 },
    { 300, 300 },
    { 300,   0 },
    {   0,   0 }
  };

  construct {
    Clutter.Color stage_color;
    Clutter.Color rect_bg_color;
    Clutter.Color rect_border_color;

    // construct a Color using its components
    stage_color = Clutter.Color () {
      red   = 0xcc,
      green = 0xcc,
      blue  = 0xcc,
      alpha = 0xff
    };
    // or parse it from hex/name
    Clutter.Color.parse ("#332222ff", out rect_bg_color);
    Clutter.Color.parse ("white", out rect_border_color);

    var stage = (Stage) Stage.get_default ();
    stage.color = stage_color;
    stage.show ();

    // first actor: a rectangle
    rect = new Clutter.Rectangle();
    rect.set_size (200, 200);
    rect.color = rect_bg_color;
    rect.border_color = rect_border_color;
    rect.border_width = 15;
    stage.add_actor (rect);
    rect.show ();

    // second actor: a texture; this actor is actually created
    // and added only if the pixbuf has been correctly loaded
    try {
      hand = new Clutter.Texture.from_file ("redhand.png");
      hand.set_position (0, 0);
      stage.add_actor (hand);
      hand.show ();
    }
    catch (Error e) {
      stderr.printf ("Unable to load redhand.png: %s", e.message);
    }

    // the timeline, used to drive the behaviours
    timeline = new Timeline (100, 26);
    timeline.loop = true;

    // the alpha, binding a function to the timeline
    var alpha = new Alpha.full (timeline, Clutter.ramp_inc_func, null, null);

    // first behaviour: used to control the opacity
    o_behave = new BehaviourOpacity (alpha, (uchar) 255, (uchar) 0x33);
    o_behave.apply (rect);
    o_behave.apply (hand);

    // second behaviour: used to move actors along a path
    p_behave = (BehaviourPath) new BehaviourPath (alpha,
                                                  poly_knots,
                                                  poly_knots.length);
    /*
    for (int i = 0; i < poly_knots.length; i++) {
      Knot k = poly_knots[i];
      p_behave.append_knot (ref k);
    }
    */
/*
    XXX - this allocates 5 knots, but a Clutter.Knot is usually put
    on the stack and copied by the methods; to do this, we have to
    declare Clutter.Knot as a value type, but it breaks the function
    below, and Clutter.BehaviourPath/BehaviourBspline don't have a 
    vector based API. hence, the iteration above; this spares us five
    allocations, and once: 1. const arrays have the length field or
    2. the path and bspline behaviours have vector based API the
    API will look nicer in vala as well.

    p_behave.append_knots (new Knot () { x =   0, y =   0 },
                           new Knot () { x =   0, y = 300 },
                           new Knot () { x = 300, y = 300 },
                           new Knot () { x = 300, y =   0 },
                           new Knot () { x =   0, y =   0 });
*/
    p_behave.apply (rect);
    p_behave.apply (hand);
  }

  // starts the test
  public void run () { timeline.start (); }

  public static void main (string[] args) {
    Clutter.init (ref args);

    var test = new TestBehave ();
    test.run ();

    Clutter.main (); 
  }
}
