using GLib;
using Cogl;
using Clutter;

public class Test.Triangle : Clutter.Actor {
  private bool is_pressed;

  [Description (nick = "color", blurb = "The color of the triangle")]
  public Clutter.Color color { get; set; }

  construct {
    color.red   = 255;
    color.green = 0;
    color.blue  = 0;
    color.alpha = 255;

    is_pressed  = false;
    reactive    = true;
  }

  private void draw_triangle (Unit width, Unit height, Color paint_color) {
    Cogl.Path.move_to (width.to_fixed () / 2, 0);

    Cogl.Path.line_to (width.to_fixed (), height.to_fixed ());
    Cogl.Path.line_to (0, width.to_fixed ());
    Cogl.Path.line_to (height.to_fixed () / 2, 0);

    Cogl.color (paint_color);
    Cogl.Path.fill ();
  }

  override void paint () {
    ActorBox box;
    this.get_allocation_box (out box);

    Clutter.Color paint_color;

    paint_color.red   = this.color.red;
    paint_color.green = this.color.green;
    paint_color.blue  = this.color.blue;
    paint_color.alpha = this.get_paint_opacity ()
                      * this.color.alpha
                      / 255;

    draw_triangle ((box.x2 - box.x1), (box.y2 - box.y1), paint_color);
  }

  override void pick (Clutter.Color pick_color) {
    if (this.should_pick_paint () == true) {
      ActorBox box;
      this.get_allocation_box (out box);

      draw_triangle (box.x2 - box.x1, box.y2 - box.y1, pick_color);
    }
  }

  public override bool button_press_event (Clutter.ButtonEvent event_) {
    if (event_.get_button () == 1) {
      this.is_pressed = true;

      return true;
    }

    return false;
  }

  public override bool button_release_event (Clutter.ButtonEvent event_) {
    uint button = event_.get_button ();

    if (button == 1 && this.is_pressed == true) {
      this.is_pressed = false;

      clicked ();

      return true;
    }

    return false;
  }

  public override bool leave_event (Clutter.CrossingEvent event_) {
    if (this.is_pressed == true) {
      this.is_pressed = false;

      return true;
    }

    return false;
  }

  public signal void clicked (); 

  public Triangle () { }

  public Triangle.with_color (Clutter.Color color) {
    this.color = color;
  }
}

class TestCustomActor : Object {
  private Clutter.Actor triangle;

  private void triangle_clicked_cb (Test.Triangle triangle) {
    stdout.printf ("Clicked!\n");
    Clutter.main_quit ();
  }

  construct {
    var stage = (Stage) Stage.get_default ();

    stage.set_size (800, 600);

    Clutter.Color bg;
    Clutter.Color.parse ("#61648cff", out bg);
    stage.set_color (bg);

    triangle = new Test.Triangle ();
    stage.add_actor (triangle);
    triangle.set_size (100, 100);
    triangle.set_position (350, 200);
    triangle.set_opacity (224);
    ((Test.Triangle) triangle).clicked += triangle_clicked_cb;

    stage.show ();
  }

  public void run () {
    Clutter.main ();
  }

  static void main (string[] args) {
    Clutter.init (ref args);

    var test = new TestCustomActor ();
    test.run ();
  }
}
