using GLib;
using Clutter;
using Pango;

class TestDepth : Object {
  public Clutter.Rectangle rect;
  public Clutter.Texture hand;
  public Clutter.Label label;
  public Clutter.BehaviourDepth behaviour;
  public Clutter.Timeline timeline;
  public bool zoom_in;

  private void timeline_completed (Timeline timeline) {
    int depth_start, depth_end;

    if (zoom_in) {
      behaviour.depth_start = 0;
      behaviour.depth_end = -500;
      zoom_in = false;
    }
    else {
      behaviour.depth_start = -500;
      behaviour.depth_end = 0;
      zoom_in = true;
    }

    timeline.rewind ();
    timeline.start ();
  }

  construct {
    Clutter.Color color;

    Clutter.Color.parse ("#ccccccff", out color);
    var stage = (Stage) Stage.get_default ();
    stage.color = color;
    stage.use_fog = true;
    stage.visible = true;

    label = new Clutter.Label ();
    label.font_name = "Mono 26";
    label.text = "Clutter\n♥\nVala";
    label.alignment = Pango.Alignment.CENTER;
    label.set_position (40, 140);
    stage.add_actor (label);
    label.show ();

    try {
      hand = new Clutter.Texture.from_file ("redhand.png");
      hand.set_position (240, 140);
      stage.add_actor (hand);
      hand.show ();
    }
    catch (Error e) {
      stderr.printf ("Unable to load redhand.png: %s", e.message);
    }

    Clutter.Color.parse ("#00000088", out color);
    rect = new Clutter.Rectangle ();
    rect.color = color;
    rect.set_position (440, 140);
    rect.set_size (200, 200);
    stage.add_actor (rect);
    rect.show ();

    timeline = new Timeline.for_duration (2500);
    timeline.completed += timeline_completed;

    var alpha = new Alpha.full (timeline, Clutter.ramp_inc_func, null, null);
    behaviour = (BehaviourDepth) new BehaviourDepth (alpha, -500, 0);
    behaviour.apply (hand);
    behaviour.apply (label);
    behaviour.apply (rect);

    zoom_in = true;
  }

  public void run () {
    timeline.start ();
    Clutter.main ();
  }

  public static void main (string[] args) {
    Clutter.init (ref args);

    var test = new TestDepth ();
    test.run ();
  }
}
