using GLib;
using Clutter;

class TestEffects : Object {
  EffectTemplate template;
  Timeline timeline;
  Stage stage;

  const Knot[] knots = {
    { 750, 210 },
    { 310, 210 }
  };

  construct {
    timeline = new Timeline.for_duration (2500);
    timeline.loop = true;

    template = new EffectTemplate (timeline, Clutter.ramp_inc_func);

    Color color = Color () {
      red   = 0xcc,
      green = 0xcc,
      blue  = 0xcc,
      alpha = 0xff
    };

    stage = (Stage) Stage.get_default ();
    stage.color = color;
    stage.use_fog = true;
    stage.set_size (800, 600);
    stage.button_press_event += (s, e) => {
      Clutter.main_quit ();
      return false;
    };

    // fade to 0x22
    var rect = create_rect (50, 10, 50, 50);
    Effect.fade (template, rect, 0x22, null, null);

    // depth to -500
    rect = create_rect (750, 70, 50, 50);
    Effect.depth (template, rect, -500, null, null);

    // move to 750, 140
    rect = create_rect (50, 140, 50, 50);
    Effect.move (template, rect, 750, 140, null, null);

    // move to 350, 210
    rect = create_rect (750, 210, 50, 50);
    Effect.path (template, rect, knots, null, null);

    // scale
    rect = create_rect (50, 280, 50, 50);
    Effect.scale (template, rect, 2.0, 2.0, null, null);

    // rotate
    rect = create_rect (750, 350, 50, 50);
    Effect.rotate (template, rect,
                   RotateAxis.Z_AXIS, 180.0,
                   25, 25, 0,
                   RotateDirection.CW,
                   null, null);
  }

  private Rectangle create_rect (int x, int y, int w, int h) {
    Color color = Color () {
      red   = 0,
      green = 0,
      blue  = 0,
      alpha = 0xdd
    };

    Rectangle rect = new Rectangle ();

    rect.color = color;
    rect.set_position (x, y);
    rect.set_size (w, h);
    stage.add_actor (rect);

    return rect;
  }

  public void run () { stage.show (); Clutter.main (); }

  public static void main (string[] args) {
    Clutter.init (ref args);

    var test = new TestEffects ();
    test.run ();
  }
}
