using GLib;
using Clutter;
using Pango;

class TestRotate : Object {
  public Clutter.Rectangle rect;
  public Clutter.Texture hand;
  public Clutter.Label label;
  public Clutter.BehaviourRotate behaviour;
  public Clutter.Timeline timeline { get; set; }

  construct {
    Clutter.Color color;

    Clutter.Color.parse ("#ccccccff", out color);
    var stage = (Stage) Stage.get_default ();
    stage.color = color;
    stage.visible = true;

    label = new Clutter.Label ();
    label.font_name = "Mono 26";
    label.text = "Clutter\n♥\nVala";
    label.alignment = Pango.Alignment.CENTER;
    label.set_position (40, 140);
    stage.add_actor (label);
    label.show ();

    try {
      hand = new Texture.from_file ("redhand.png");
      hand.set_position (240, 140);
      stage.add_actor (hand);
      hand.show ();
    }
    catch (Error e) {
      stderr.printf ("Unable to load redhand.png: %s", e.message);
    }
    
    Clutter.Color.parse ("#00000088", out color);

    rect = new Clutter.Rectangle ();
    rect.color = color;
    rect.set_position (440, 140);
    rect.set_size (200, 200);
    stage.add_actor (rect);
    rect.show ();

    timeline = new Timeline.for_duration (3000);
    timeline.loop = true;

    var alpha = new Alpha.full (timeline, Clutter.ramp_inc_func, null, null);
    behaviour = (BehaviourRotate) new BehaviourRotate (alpha,
                                                       RotateAxis.Z_AXIS,
                                                       RotateDirection.CW,
                                                       0.0, 360.0);
    behaviour.set_center (86, 125, 0);
    behaviour.apply (label);
    behaviour.apply (hand);
    behaviour.apply (rect);

    stage.show_all ();
  }

  public void run () { timeline.start (); }

  public static void main (string[] args) {
    Clutter.init (ref args);

    var test = new TestRotate ();
    test.run ();

    Clutter.main ();
  }
}
