using GLib;
using Clutter;

class TestScale : Object {
  public Rectangle rect;
  public BehaviourScale behaviour;
  public Timeline timeline;
  public int gindex;

  const Gravity[] gravities = {
      Gravity.NORTH_EAST,
      Gravity.NORTH,
      Gravity.NORTH_WEST,
      Gravity.WEST,
      Gravity.SOUTH_WEST,
      Gravity.SOUTH,
      Gravity.SOUTH_EAST,
      Gravity.EAST,
      Gravity.CENTER,
      Gravity.NONE
  };

  construct {
    gindex = 0;

    Color stage_color = Color () {
      red = (uchar) 0,
      green = (uchar) 0,
      blue = (uchar) 0,
      alpha = (uchar) 255
    };

    var stage = (Stage) Stage.get_default ();
    stage.color = stage_color;
    stage.width = 300;
    stage.height = 300;
    stage.visible = true;

    Color rect_color;
    Color.parse ("White", out rect_color);

    rect_color.alpha = (uchar) 0x99;
    Rectangle base_rect = new Rectangle ();
    base_rect.color = rect_color;
    base_rect.set_size (100, 100);
    base_rect.set_position (100, 100);
    stage.add_actor (base_rect);
    base_rect.show ();

    rect_color.alpha = (uchar) 255;
    rect = new Rectangle ();
    rect.color = rect_color;
    rect.set_size (100, 100);
    rect.set_position (100, 100);
    rect.move_anchor_point_from_gravity (Gravity.CENTER);
    stage.add_actor (rect);
    rect.show ();

    timeline = new Timeline.for_duration (750);
    timeline.loop = true;
    timeline.completed += on_timeline_completed;

    var alpha = new Alpha.full (timeline, Clutter.ramp_func, null, null);

    behaviour = (BehaviourScale) new BehaviourScale (alpha,
                                                     0.0, 0.0,
                                                     1.0, 1.0);
    behaviour.apply (rect);

    stage.show_all ();
  }

  private void on_timeline_completed (Timeline timeline) {
        if (++gindex >= gravities.length) {
          gindex = 0;
        }

        rect.move_anchor_point_from_gravity (gravities[gindex]);
  }

  public void run () { timeline.start (); }

  public static void main (string[] args) {
    Clutter.init (ref args);

    var test = new TestScale ();
    test.run ();

    Clutter.main ();
  }
}
